/* modemst6.h   */

/* data structures created by  Tom Jennings  */

#define FIGS 27	   /* Baudot FIGS character and case machine state */
#define LTRS 31	   /* Baudot LTRS character and case machine state */
#define BOTH 0	    /* case machine state */
#define NEITHER 99 /* initial case machine state */
#define UU 127	    /* untranslatable character */
#define FIGS 27
#define LTRS 31

/* ASCII characters */
#define UU 127	/* untranslatable character */
#define NUL 0
#define LF 10
#define CR 13
#define BEL 7

/* Baudot characters */
#define BCR 8
#define BSP 4
#define BLF 2

/* Table of Baudot characters in ASCII order, in a crude double-character
format. Index is [2 * i] for the case indicator; [2 * i + 1] is the Baudot
character. The first symbol defines which code set (FIGS, LTRS) the
character is in. */
struct
{
			unsigned int state;
			char         baudot;
}	table3[] = {
			{	BOTH, 0 }, /* NULL */
			{	BOTH, UU},  /* soh */
			{	BOTH, UU},  /* stx */
			{	BOTH, UU},  /* etx */
			{	BOTH, UU},  /* eot */
			{	BOTH, UU},  /* enq */
			{	BOTH, UU},  /* ack */
			{	FIGS, 5 }, /* bell */
			{	BOTH, UU},  /* bs */
			{	BOTH, UU},  /* ht */
			{	BOTH, 2 }, /* LF */
			{ BOTH, UU},  /* vt */
			{ BOTH, UU},  /* ff */
			{ BOTH, 8 }, /* CR */
			{ BOTH, UU},  /* so */
			{ BOTH, UU},  /* si */
			{ BOTH, UU},  /* dle */
			{ BOTH, UU},  /* dc1 */
			{ BOTH, UU},  /* dc2 */
			{ BOTH, UU},  /* dc3 */
			{ BOTH, UU},  /* dc4 */
			{ BOTH, UU},  /* nak */
			{ BOTH, UU},  /* syn */
			{ BOTH, UU},  /* etb */
			{ BOTH, UU},  /* can */
			{	BOTH, UU},  /* em */
			{ BOTH, UU},  /* sub */
			{ BOTH, FIGS},  /* FIGS */
			{ BOTH, UU},  /* fs */
			{ BOTH, UU},  /* gs */
			{	BOTH, UU},  /* rs */
			{ BOTH, LTRS},  /* LTRS */
			{ BOTH, 4}, /* SPACE */
			{ FIGS, 13}, /*  (exclamation) */
			{ FIGS, 17}, /* " */
			{ FIGS, 20}, /* # */
			{ FIGS, 9},  /*  (dollar) */
			{ BOTH, UU}, /*  (percent) */
			{	FIGS, 26}, /*  */
			{ FIGS, 11}, /*  (sgl quote) */
			{ FIGS, 15}, /* ( */
			{ FIGS, 18 }, /* ) */
			{ BOTH, UU }, /* * (asterisk) */
			{ BOTH, UU }, /* + (plus) */
			{ FIGS, 12 }, /* , */
			{ FIGS, 3  },/* - */
			{ FIGS, 28 }, /* . */
			{ FIGS, 29 },  /* / */
			{ FIGS, 22 }, /* 0 */
			{ FIGS, 23 }, /* 1 */
			{ FIGS, 19 }, /* 2 */
			{ FIGS, 1  },/* 3 */
			{ FIGS, 10 }, /* 4 */
			{ FIGS, 16 }, /* 5 */
			{ FIGS, 21 }, /* 6 */
			{ FIGS, 7  },/* 7 */
			{ FIGS, 6  },/* 8 */
			{	FIGS, 24 }, /* 9 */
			{	FIGS, 14 }, /* : */
			{ FIGS, 30 }, /* ; */
			{ BOTH, UU }, /* (.LT.) */
			{ BOTH, UU }, /* (equal) */
			{	BOTH, UU }, /* (.GT.) */
			{ FIGS, 25 }, /* ? */
			{ BOTH, UU }, /* (at) */
			{ LTRS, 3 },/* A */
			{ LTRS, 25 }, /* B */
			{ LTRS, 14 }, /* C */
			{ LTRS, 9  },/* D */
			{ LTRS, 1  },/* E */
			{	LTRS, 13 }, /* F */
			{ LTRS, 26 }, /* G */
			{ LTRS, 20 }, /* H */
			{ LTRS, 6  },/* I */
			{ LTRS, 11 }, /* J */
			{ LTRS, 15 }, /* K */
			{ LTRS, 18 }, /* L */
			{ LTRS, 28 }, /* M */
			{ LTRS, 12 }, /* N */
			{ LTRS, 24 }, /* O */
			{ LTRS, 22 }, /* P */
			{ LTRS, 23 }, /* Q */
			{ LTRS, 10 }, /* R */
			{ LTRS, 5  },/* S */
			{ LTRS, 16 }, /* T */
			{ LTRS, 7  },/* U */
			{ LTRS, 30 }, /* V */
			{ LTRS, 19 }, /* W */
			{	LTRS, 29 }, /* X */
			{	LTRS, 21 }, /* Y */
			{ LTRS, 17 }, /* Z */
			{	BOTH, UU }, /* [ (L bkt) */
			{ BOTH, UU }, /* \ (back sl) */
			{ BOTH, UU }, /* ] (R bkt) */
			{	BOTH, UU }, /* ^ (caret) */
			{ BOTH, UU }, /* _ (underscore) */
};

/* This table does the translation; it contains 64ASCII characters in
Baudot order. The table is indexed by [baudot char + state]; state is
set to 0 (first 32 chars, FIGS code set) or 32 (last 32 characters,
LTRS code set) when a FIGS or LTRS character is dectected in the
character stream. */
char table1[] = {
/* LTRS */ 	NUL, 'E',  LF, 'A', ' ', 'S', 'I', 'U',
													CR, 'D', 'R', 'J', 'N', 'F', 'C', 'K',
												'T', 'Z', 'L', 'W', 'H', 'Y', 'P', 'Q',
												'O', 'B', 'G',  UU, 'M', 'X', 'V', UU,
/* FIGS */  NUL, '3',  LF, '-', ' ', BEL, '8', '7',
													CR, '$', '4', '\'', ',', '!', ':', '(',
												'5', '"', ')', '2', '#', '6', '0', '1',
												'9', '?', '&',  UU, '.', '/', ';', UU };


/* Same as above but with printable characters' bits flipped! */
char table2[] = {
/* LTRS */ 	NUL, 'T',  LF, 'O', ' ', 'H', 'N', 'M',
													CR, 'L', 'R', 'G', 'I', 'P', 'C', 'V',
												'E', 'Z', 'D', 'B', 'S', 'Y', 'F', 'X',
												'A', 'W', 'J',  UU, 'U', 'Q', 'K', UU,
/* FIGS */  NUL, '5',  LF, '9', ' ', '#', ',', '.',
													CR, ')', '4', '&', '8', '0', ':', ';',
												'5', '"', '$', '?', BEL, '6', '!', '/',
												'-', '2', '\'',  UU, '7', '1', '(', UU };

char state= 0;					/* assume initial LTRS state */
char last_state= NEITHER;			/* unspecified state */

	char * morsecode[] = {
		/* */  "3     ",  /* first offset = 32 space */
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/*'*/  "3     ",  
		/*(*/  "212212",
		/*)*/  "212212",
		/*ack*/"3     ",
		/*+*/  "3     ",
		/*,*/  "221122",
		/*-*/  "22122 ",
		/*.*/  "121212",
		/*/*/  "21121 ",
		/*0*/  "22222 ",
		/*1*/  "12222 ",
		/*2*/  "11222 ",
		/*3*/  "11122 ",
		/*4*/  "11112 ",
		/*5*/  "11111 ",
		/*6*/  "21111 ",
		/*7*/  "22111 ",
		/*8*/  "22211 ",
		/*9*/  "22221 ",
		/*:*/  "111222",
		/*;*/  "212121",
		/*<*/  "3     ",
		/*=*/  "3     ",
		/*>*/  "3     ",
		/*?*/  "112211",
		/*@*/  "3     ",
		/*A*/  "12    ",
		/*B*/  "2111  ",
		/*C*/  "2121  ",
		/*D*/  "211   ",
		/*E*/  "1     ",
		/*F*/  "1121  ",
		/*G*/  "221   ",
		/*H*/  "1111  ",
		/*I*/  "11    ",
		/*J*/  "1222  ",
		/*K*/  "212   ",
		/*L*/  "1211  ",
		/*M*/  "22    ",
		/*N*/  "21    ",
		/*O*/  "222   ",
		/*P*/  "1221  ",
		/*Q*/  "2212  ",
		/*R*/  "121   ",
		/*S*/  "111   ",
		/*T*/  "2     ",
		/*U*/  "112   ",
		/*V*/  "1112  ",
		/*W*/  "122   ",
		/*X*/  "2112  ",
		/*Y*/  "2122  ",
		/*Z*/  "2211  ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     ",
		/* */  "3     "
				};


